@@ -14,7 +14,7 @@ has 'backend';
 has remove_after => 864000;
 has tasks => sub { {} };
 
-our $VERSION = '0.45';
+our $VERSION = '1.0';
 
 sub add_task {
   my ($self, $name, $cb) = @_;
@@ -126,9 +126,6 @@ L<Minion::Command::minion::job>.
 
   $ ./myapp.pl minion job
 
-Note that this whole distribution is EXPERIMENTAL and will change without
-warning!
-
 =head1 EVENTS
 
 L<Minion> inherits all events from L<Mojo::EventEmitter> and can emit the
